# snoop-tensor
Numpy/Pytorch Tensor extension for snoop. It's modified from [TorchSnooper](https://github.com/zasdfgbnm/TorchSnooper)

# Usage

```python
import snoop, snoop_tensor
snoop.install()
snoop_tensor.register() # need to be called after install()
```

## Features

- Display tensors in a beautiful way
- Profiling GPU memory usage and time usage
